#Pour que le programme marche, il faut rajouter les variables d'environnement suivantes à votre système:
#SPOTIPY_CLIENT_ID
#SPOTIPY_CLIENT_SECRET
#SPOTIPY_REDIRECT_URI
#Pour les obtenir, il faut créer une application sur le site de spotify => https://developer.spotify.com/dashboard/applications

#Imports
from signal import SIGTERM
import spotipy
from spotipy.oauth2 import SpotifyOAuth
from pynput import keyboard

#Authentification et portée de l'application
scope = "user-library-read playlist-modify-public playlist-modify-private playlist-read-collaborative playlist-read-private"
sp = spotipy.Spotify(auth_manager=SpotifyOAuth(scope=scope))

#1 - Récupération de la playlist
def get_playlist():
    print("Récupération des playlist...")
    playlists = sp.current_user_playlists(limit=50)
    print("Choisissez une playlist :")
    for i, item in enumerate(playlists['items']):
        print("%d %s" % (i, item['name']))
    print()
    choice = int(input("Choix : "))
    playlist = playlists['items'][choice]['uri']
    return playlist


#2 - Récupération des chansons de la playlist
def get_tracks(playlist):
    print("Récupération des chansons...", end="")
    results = sp.playlist_tracks(playlist)
    tracks = results['items']
    while results['next']:
        results = sp.next(results)
        tracks.extend(results['items'])

    songs = []
    for track in tracks:
        songs.append(track['track']['uri'])
    print("✅")
    return songs

#3 - Récupération de la popularité des chansons
def get_popularity(songs):
    print("Analyse des chansons...", end="")
    popularity = []
    for i in range(len(songs)):
        track = sp.track(songs[i])
        popularity.append(track['popularity'])
    print("✅")
    return popularity

#4 - Tri de la playlist
def sort_playlist(songs, popularity):
    print("Tri de la playlist...", end="")
    for i in range(len(popularity)):
        for j in range(len(popularity)-1):
            if popularity[j] < popularity[j+1]:
                popularity[j], popularity[j+1] = popularity[j+1], popularity[j]
                songs[j], songs[j+1] = songs[j+1], songs[j]
    print("✅")
    return songs

# 5 - Création de la nouvelle playlist
def create_playlist(songs):
    name = input("Nom de la nouvelle playlist : ")
    sp.user_playlist_create(user=sp.current_user()['id'], name=name, public=False, collaborative=False, description='')
    playlist = sp.current_user_playlists(limit=1)['items'][0]['uri']
    print("Creaion de la playlist...", end="")

    # Split songs into batches of 100 tracks
    batches = [songs[i:i+100] for i in range(0, len(songs), 100)]

    # Add each batch of tracks to the playlist
    for batch in batches:
        sp.playlist_add_items(playlist, batch)

    print("✅")
    return playlist



#6 - Suppression de la playlist
def delete_playlist(playlist):
    sp.playlist_unfollow(playlist)

#MAIN
def main():
    playlist = get_playlist()
    songs = get_tracks(playlist)
    popularity = get_popularity(songs)
    songs = sort_playlist(songs, popularity)
    new_playlist = create_playlist(songs)
    #delete_playlist(playlist)
    print("Voulez-vous trier une autre playlist ? (y/n)")
    choice = input()
    if choice == "y":
        main()
    else:
        exit()
main()